@@ -15,12 +15,10 @@ def get_bit(buffer, ref_pointer, ref_filter, length):
     return result
 
 def decompress(buffer, decode, length):
-    ref_pointer = Ref()
-    ref_pointer.value = 0
-    ref_filter = Ref()
-    ref_filter.value = 0x80
+    ref_pointer = Ref(0)
+    ref_filter = Ref(0x80)
     dest = 0
-    dic = [0 for i in range(0x2010)]
+    dic = [0] * 0x2010
     while ref_pointer.value < length:
         bits = get_bit(buffer, ref_pointer, ref_filter, 1)
         if ref_pointer.value >= length:
@@ -73,11 +71,3 @@ def decode(buffer, length, block_size, base, add):
             tp2 -= 2
             p += 1
         left -= block_size
-
-def entry(file):
-    buffer = bytearray(0x100000)
-    with open(file, 'rb') as f:
-        _buffer = f.read()
-    flength = len(_buffer)
-    buffer[:flength] = _buffer
-    return file, buffer, flength
\ No newline at end of file
