@@ -1,81 +1,68 @@
-from math import ceil, floor
+from math import ceil
 from time import localtime
 
-from threp.utils import unsigned_int, unsigned_char, float_
-from threp.common import decode, decompress, entry
-from threp.static import work_attr, skeys, kkeys, oldwork_magicnumber_flc
+from threp.utils import unsigned_int, unsigned_char, float_, filter_constant_frame, true_frame, correct_true_frame, entry
+from threp.common import decode, decompress
+from threp.static import work_attr, skeys, kkeys, oldwork_magicnumber_flc, newwork_magicnumber_flc, old_types_dic
 from threp.type import get_alltypes, format_types
 
 def threp_decodedata(buffer):
     work_magicnumber = unsigned_int(buffer, 0)
     if work_magicnumber in oldwork_magicnumber_flc:
         return oldworkrep_cut(oldwork_magicnumber_flc[work_magicnumber], buffer)
-    is_2hu_replay = False
-    for key, value in work_attr.items():
-        if work_magicnumber == value['magic_number']:
-            is_2hu_replay = True
-            work = key
-    if is_2hu_replay:
+    if work_magicnumber in newwork_magicnumber_flc:
+        work = newwork_magicnumber_flc[work_magicnumber]
+        rep_attr = work_attr[work]
         length = unsigned_int(buffer, 0x1c)
         dlength = unsigned_int(buffer, 0x20)
         decodedata = bytearray(dlength)
         rawdata = bytearray(buffer[0x24:])
-        decode(rawdata, length, work_attr[work]['decode_var1'], work_attr[work]['decode_var2'],
-               work_attr[work]['decode_var3'])
-        decode(rawdata, length, work_attr[work]['decode_var4'], work_attr[work]['decode_var5'],
-               work_attr[work]['decode_var6'])
+        decode(rawdata, length, rep_attr['decode_var1'], rep_attr['decode_var2'],
+               rep_attr['decode_var3'])
+        decode(rawdata, length, rep_attr['decode_var4'], rep_attr['decode_var5'],
+               rep_attr['decode_var6'])
         decompress(rawdata, decodedata, length)
         return decodedata, work
     raise Exception("Bad file magic number")
 
 def threp_cut(decodedata, work, frameignore = False):
-    info = {'stages': {}, 'stage': None,
-            'character': None, 'ctype': None, 'rank': None, 'clear': None, 'player': '', 'slowrate': None, 'date': None, 'error':[]}
+    info = {'stages': {}, 'error':[]}
+
+    rep_attr = work_attr[work]
 
     # f=open('rep161.txt', 'wb')
     # f.write(decodedata)
     # f.close()
 
-    stage = decodedata[work_attr[work]['stage']]
-    character = unsigned_char(decodedata, work_attr[work]['character'])
-    ctype = unsigned_char(decodedata, work_attr[work]['ctype'])
-    rank = unsigned_char(decodedata, work_attr[work]['rank'])
-    clear = unsigned_char(decodedata, work_attr[work]['clear'])
-    date = localtime(unsigned_int(decodedata, work_attr[work]['date']))
+    stage = decodedata[rep_attr['stage']]
 
-    info['stage'] = stage
-    info['character'] = character
-    info['ctype'] = ctype
-    info['rank'] = rank
-    info['clear'] = clear
+    info['character'] = unsigned_char(decodedata, rep_attr['character'])
+    info['ctype'] = unsigned_char(decodedata, rep_attr['ctype'])
+    info['rank'] = unsigned_char(decodedata, rep_attr['rank'])
+    info['clear'] = unsigned_char(decodedata, rep_attr['clear'])
+    info['slowrate'] = round(float_(decodedata, rep_attr['slowrate']), 2)
+    date = localtime(unsigned_int(decodedata, rep_attr['date']))
+    info['date'] = f"{date[0]}/{date[1]:02d}/{date[2]:02d} {date[3]:02d}:{date[4]:02d}"
 
-    if work=='95':
+    if work in ['95']:
         info['player'] = "".join(chr(unsigned_char(decodedata, i)) for i in range(7, 15)).strip()
         info['character'] = 0
     else:
         info['player'] = "".join(chr(unsigned_char(decodedata, i)) for i in range(8)).strip()
 
-    info['slowrate']=round(float_(decodedata, work_attr[work]['slowrate']), 2)
-    info['date'] = f"{date[0]}/{date[1]:02d}/{date[2]:02d} {date[3]:02d}:{date[4]:02d}"
+    stagedata = rep_attr['stagedata']
+    stagedata_t = rep_attr['stagedata'] + rep_attr['stagedata_offset']
 
-    stagedata = work_attr[work]['stagedata']
-    stagedata_t = work_attr[work]['stagedata'] + work_attr[work]['stagedata_offset']
+    score = []
 
-    score = list(range(6))
-
-    if work=='125' or work=='143' or work=='95' or work=='165':
-        score[0] = unsigned_int(decodedata, work_attr[work]['totalscoredata'])
-        info['stage']=1
-        stage=1
+    if work in ['125', '143', '95', '165']:
+        score.append(unsigned_int(decodedata, rep_attr['totalscoredata']))
+        stage = 1
     else:
         for i in range(1, stage):
             frame = unsigned_int(decodedata, stagedata_t + 0x4)
             llength = unsigned_int(decodedata, stagedata_t + 0x8)
-            if frame * 6 + ceil(frame / 30) == llength:
-                pass
-            elif frame * 3 + ceil(frame / 30) == llength:
-                pass
-            else:
+            if (frame * 6 + ceil(frame / 30) != llength) and (frame * 3 + ceil(frame / 30) != llength):
                 if frameignore:
                     try:
                         true_frame(llength)
@@ -93,24 +80,25 @@ def threp_cut(decodedata, work, frameignore = False):
                     info['error'].append({'type': "length read error",
                                           'message': f"{i}面，读取到的单面帧数：{frame}，读取到的单面长度：{llength}，帧数计算出的单面长度：{frame * 6 + ceil(frame / 30)}，判断为单面长度出错"})
                     llength = frame * 6 + ceil(frame / 30)
-            stagedata_t += llength + work_attr[work]['replaydata_offset']
-            stagedata += work_attr[work]['replaydata_offset'] + llength
-            score[i - 1] = unsigned_int(decodedata, stagedata + 0xc)
-        score[stage - 1] = unsigned_int(decodedata, work_attr[work]['totalscoredata'])
+            stagedata_t += (llength + rep_attr['replaydata_offset'])
+            stagedata += (llength + rep_attr['replaydata_offset'])
+            score.append(unsigned_int(decodedata, stagedata + 0xc))
+        score.append(unsigned_int(decodedata, rep_attr['totalscoredata']))
 
-    stagedata = work_attr[work]['stagedata'] + work_attr[work]['stagedata_offset']
+    info['stage'] = stage
 
-    for l in range(stage):
-        stage_info = {'score': None, 'frame': None,
-                      'replay': {}}
+    stagedata = rep_attr['stagedata'] + rep_attr['stagedata_offset']
 
-        replaydata = stagedata + work_attr[work]['replaydata_offset']
+    for i in range(stage):
+        stage_info = {}
+
+        replaydata = stagedata + rep_attr['replaydata_offset']
         frame = unsigned_int(decodedata, stagedata + 0x4)
         llength = unsigned_int(decodedata, stagedata + 0x8)
 
-        if work=='95' or work=='165':
-            perframe=6
-            frame=int(llength/6)-2
+        if work in ['95', '165']:
+            perframe = 6
+            frame = int(llength / 6) - 2
         else:
             if frame * 6 + ceil(frame / 30) == llength:
                 perframe = 6
@@ -120,19 +108,18 @@ def threp_cut(decodedata, work, frameignore = False):
                 if frameignore:
                     # 忽略帧数，强制保留单面长度
                     frame = correct_true_frame(llength)
-                    perframe = 6
                 else:
                     # rep单面长度出错
                     llength = frame * 6 + ceil(frame / 30)
-                    perframe = 6
+                perframe = 6
 
-        stage_info['score'] = score[l]
+        stage_info['score'] = score[i]
         stage_info['frame'] = frame
         stage_info['replay'] = decodedata[replaydata: (replaydata + (frame * perframe))]
 
-        info['stages'][l] = stage_info
+        info['stages'][i] = stage_info
 
-        stagedata += llength + work_attr[work]['replaydata_offset']
+        stagedata += (llength + rep_attr['replaydata_offset'])
 
     return info
 
@@ -163,47 +150,38 @@ def hmxrep_cut(dat):
     # f.write(decodedata)
     # f.close()
 
-    date = decodedata[0x10:0x10 + 8]
-    name = decodedata[0x19:0x19 + 8]
-    char = decodedata[0x06]
-    rank = decodedata[0x07]
-    drop = float_(decodedata, 0x2c)
-
-    date = date.strip().decode()
-    date = f"20{date[6:8]}/{date[:2]}/{date[3:5]}"
-    rep_info['date'] = date.strip()
-    rep_info['player'] = name.strip().decode()
-    chars = ("Reimu A", "Reimu B", "Marisa A", "Marisa B")
-    levels = ("Easy", "Normal", "Hard", "Lunatic", "Extra")
-    rep_info['base_info'] = f"{chars[char]} {levels[rank]}"
+    rep_info['player'] = decodedata[0x19:0x19 + 8].strip().decode()
+    char = old_types_dic['06']['character'][decodedata[0x06]]
+    rank = old_types_dic['06']['rank'][decodedata[0x07]]
+    rep_info['base_info'] = f"{char} {rank}"
     rep_info['base_infos'] = {
-        "character": chars[char].split(" ")[0],
-        "shottype": chars[char].split(" ")[1],
-        "rank": levels[rank],
+        "character": char.split(" ")[0],
+        "shottype": char.split(" ")[1],
+        "rank": rank,
         "stage": ""
     }
-    rep_info['slowrate'] = round(drop, 3)
+    rep_info['slowrate'] = round(float_(decodedata, 0x2c), 3)
+    date = decodedata[0x10:0x10 + 8].strip().decode()
+    rep_info['date'] = f"20{date[6:8]}/{date[:2]}/{date[3:5]}".strip()
 
     rep_info['stage_score'] = []
     rep_info['screen_action'] = []
     rep_info['keyboard_action'] = []
-
     rep_info['z_frame'] = []
     rep_info['x_frame'] = []
     rep_info['c_frame'] = []
     rep_info['shift_frame'] = []
-
     total_frame_count=0
 
     for i in range(7):
-        stage_offset=unsigned_int(decodedata, 0x34 + i * 0x4)
-        if stage_offset!=0:
+        stage_offset = unsigned_int(decodedata, 0x34 + i * 0x4)
+        if stage_offset != 0:
             rep_info['stage_score'].append(unsigned_int(decodedata, stage_offset))
             replay_offset=stage_offset + 0x10
             stage_replaydata=[]
-            i=0x0
-            frame=unsigned_int(decodedata, replay_offset + i)
-            while frame!=9999999:
+            i = 0x0
+            frame = unsigned_int(decodedata, replay_offset + i)
+            while frame != 9999999:
                 # 检测 z x c shift
                 left_hand_flag = unsigned_int(decodedata, replay_offset + i + 0x4) & 0xf
                 frame_dic = {
@@ -213,32 +191,32 @@ def hmxrep_cut(dat):
                 }
                 if left_hand_flag in frame_dic:
                     rep_info[frame_dic[left_hand_flag]].append(frame)
-                press=(unsigned_int(decodedata, replay_offset + i + 0x4) >> 4) & 0xf
-                i+=0x8
+                press = (unsigned_int(decodedata, replay_offset + i + 0x4) >> 4) & 0xf
+                i += 0x8
                 stage_replaydata.append([frame, press])
                 frame = unsigned_int(decodedata, replay_offset + i)
-            kkey=[]
-            skey=[]
+            kkey = []
+            skey = []
             frame_count = 0
             for i in range(len(stage_replaydata)-1):
                 for index in range(stage_replaydata[i][0], stage_replaydata[i+1][0]):
-                    if (frame_count % 60 == 0):
+                    if frame_count % 60 == 0:
                         skey.append(f'[{(frame_count // 60):<6}]')
-                    skey.append(skeys[stage_replaydata[i][1]])
-                    kkey.append(kkeys[stage_replaydata[i][1]])
+                    framekey = stage_replaydata[i][1]
+                    skey.append(skeys[framekey])
+                    kkey.append(kkeys[framekey])
                     if (frame_count + 1) % 60 == 0:
                         rep_info['screen_action'].append(''.join(skey))
                         rep_info['keyboard_action'].append(kkey)
                         skey = []
                         kkey = []
-                    frame_count+=1
+                    frame_count += 1
                     total_frame_count += 1
             rep_info['screen_action'].append(''.join(skey))
             rep_info['keyboard_action'].append(kkey)
 
-    rep_info['error']=[]
-
-    rep_info['frame_count']=total_frame_count
+    rep_info['error'] = []
+    rep_info['frame_count'] = total_frame_count
 
     return rep_info
 
@@ -372,32 +350,23 @@ def yymrep_cut(dat):
     # f.write(decodedata)
     # f.close()
 
-    date = decodedata[0x58:0x58+5]
-    name = decodedata[0x5e:0x5e+8]
-    char = decodedata[0x56]
-    rank = decodedata[0x57]
-    drop = float_(decodedata, 0xcc)
-
-    rep_info['date'] = date.strip().decode()
-    rep_info['player'] = name.strip().decode()
-    chars = ("Reimu A", "Reimu B", "Marisa A", "Marisa B", "Sakuya A", "Sakuya B")
-    levels = ("Easy","Normal","Hard","Lunatic","Extra","Phantasm")
-    rep_info['base_info'] = f"{chars[char]} {levels[rank]}"
+    rep_info['player'] = decodedata[0x5e:0x5e+8].strip().decode()
+    char = old_types_dic['07']['character'][decodedata[0x56]]
+    rank = old_types_dic['07']['rank'][decodedata[0x57]]
+    rep_info['base_info'] = f"{char} {rank}"
     rep_info['base_infos'] = {
-        "character": chars[char].split(" ")[0],
-        "shottype": chars[char].split(" ")[1],
-        "rank": levels[rank],
+        "character": char.split(" ")[0],
+        "shottype": char.split(" ")[1],
+        "rank": rank,
         "stage": ""
     }
-    rep_info['slowrate'] = round(drop, 3)
+    rep_info['slowrate'] = round(float_(decodedata, 0xcc), 3)
+    rep_info['date'] = decodedata[0x58:0x58 + 5].strip().decode()
+
+    is_extra_or_phantasm = (unsigned_int(decodedata, 0x34)!=0)
+    is_onestage = (unsigned_int(decodedata, 0x1c) == 0)
+
     rep_info['stage_score'] = []
-    rep_info['screen_action'] = []
-    rep_info['keyboard_action'] = []
-
-    is_extra_or_phantasm=(unsigned_int(decodedata, 0x34)!=0)
-
-    is_onestage=(unsigned_int(decodedata, 0x1c) == 0)
-
     stage_offsets = []
 
     if is_extra_or_phantasm:
@@ -426,30 +395,31 @@ def yymrep_cut(dat):
 
         stage_offsets.append(stage_end)
 
+    rep_info['screen_action'] = []
+    rep_info['keyboard_action'] = []
     rep_info['z_frame'] = []
     rep_info['x_frame'] = []
     rep_info['c_frame'] = []
     rep_info['shift_frame'] = []
-
-    total_frame_count=0
+    total_frame_count = 0
 
     for i in range(len(stage_offsets)-1):
         start = stage_offsets[i] + 0x28
-        frame = int((stage_offsets[i+1]-stage_offsets[i]-0x28)/4)
+        frame = int((stage_offsets[i+1] - stage_offsets[i] - 0x28) / 4)
         skey = []
         kkey = []
         for j in range(frame):
-            if (j % 60 == 0):
+            if j % 60 == 0:
                 skey.append(f'[{(j // 60):<6}]')
             framekey = unsigned_int(decodedata, start + j * 4) >> 4 & 0xf
             skey.append(skeys[framekey])
             kkey.append(kkeys[framekey])
-            if ((j + 1) % 60 == 0):
+            if (j + 1) % 60 == 0:
                 rep_info['screen_action'].append(''.join(skey))
                 rep_info['keyboard_action'].append(kkey)
                 skey = []
                 kkey = []
-            total_frame_count+=1
+            total_frame_count += 1
             # 检测 z x c shift
             left_hand_flag = unsigned_int(decodedata, start + j * 4) & 0xf
             frame_dic = {
@@ -463,9 +433,7 @@ def yymrep_cut(dat):
         rep_info['keyboard_action'].append(kkey)
 
     rep_info['error'] = []
-
     rep_info['frame_count'] = total_frame_count
-
     rep_info['z_frame'] = filter_constant_frame(rep_info['z_frame'])
     rep_info['x_frame'] = filter_constant_frame(rep_info['x_frame'])
     rep_info['shift_frame'] = filter_constant_frame(rep_info['shift_frame'])
@@ -501,39 +469,26 @@ def yycrep_cut(dat):
     # f.write(mergedecodedata)
     # f.close()
 
-    decodedata=mergedecodedata
+    decodedata = mergedecodedata
 
-    date = decodedata[0x6c:0x6c + 5]
-    name = decodedata[0x72:0x72 + 8]
-    char = decodedata[0x6a]
-    rank = decodedata[0x6b]
-    drop = float_(decodedata, 0x118)
-
-    rep_info['date'] = date.strip().decode()
-    rep_info['player'] = name.strip().decode()
-    chars = ("Rm & Yk", "Ms & Al", "Sk & Rr", "Ym & Yy", "Reimu", "Yukari", "Marisa", "Alice", "Sakuya", "Remilia", "Youmu", "Yuyuko")
-    levels = ("Easy", "Normal", "Hard", "Lunatic", "Extra")
-    spellid=decodedata[0x7c]+256*decodedata[0x7d]
+    rep_info['player'] = decodedata[0x72:0x72 + 8].strip().decode()
+    char = old_types_dic['08']['character'][decodedata[0x6a]]
+    rank = old_types_dic['08']['rank'][ decodedata[0x6b]]
+    spellid = decodedata[0x7c]+256*decodedata[0x7d]
+    rep_info['base_info'] = f"{char} {rank}" if spellid == 65535 else f"{char} Spell No.{spellid + 1}"
     rep_info['base_infos'] = {
-        "character": chars[char],
+        "character": char,
         "shottype": "",
-        "stage": ""
+        "rank": rank if spellid == 65535 else f"Spell No.{spellid + 1}",
+        "stage": "",
     }
-    if spellid!=65535:
-        rep_info['base_info'] = f"{chars[char]} Spell No.{spellid+1}"
-        rep_info['base_infos']['rank'] = f"Spell No.{spellid+1}"
-    else:
-        rep_info['base_info'] = f"{chars[char]} {levels[rank]}"
-        rep_info['base_infos']['rank'] = levels[rank]
-    rep_info['slowrate'] = round(drop, 3)
-    rep_info['stage_score'] = []
-    rep_info['screen_action'] = []
-    rep_info['keyboard_action'] = []
+    rep_info['slowrate'] = round(float_(decodedata, 0x118), 3)
+    rep_info['date'] = decodedata[0x6c:0x6c + 5].strip().decode()
 
     is_extra = (unsigned_int(decodedata, 0x40) != 0)
-
     is_onestage = (unsigned_int(decodedata, 0x20) == 0)
 
+    rep_info['stage_score'] = []
     stage_offsets = []
 
     stage_dic = {
@@ -577,6 +532,8 @@ def yycrep_cut(dat):
 
         stage_offsets.append(stage_end)
 
+    rep_info['screen_action'] = []
+    rep_info['keyboard_action'] = []
     rep_info['z_frame'] = []
     rep_info['x_frame'] = []
     rep_info['c_frame'] = []
@@ -654,27 +611,20 @@ def hyzrep_cut(dat):
 
     decodedata = mergedecodedata
 
-    date = decodedata[0xc4:0xc4 + 8]
-    name = decodedata[0xcd:0xcd + 8]
-    rank = decodedata[0xd7]
-    mode = decodedata[0x1e4]+decodedata[0x1e5]
-
-    rep_info['date'] = date.strip().decode()
-    rep_info['player'] = name.strip().decode()
-    chars = ("Reimu", "Marisa", "Sakuya", "Youmu", "Reisen", "Cirno", "Lyrica", "Mystia", "Tewi", "Yuka", "Aya", "Medicine", "Komachi", "Sikieiki", "Marlin", "Lunasa")
-    levels = ("Easy", "Normal", "Hard", "Lunatic", "Extra")
-    modes = ('Story Mode', 'Extra Mode', 'Human vs Human', 'Human vs Com', 'Com vs Human', 'Com vs Com')
-    rep_info['base_info'] = f"{levels[rank]} {modes[mode]}"
+    rep_info['player'] = decodedata[0xcd:0xcd + 8].strip().decode()
+    chars = old_types_dic['09']['character']
+    rank = old_types_dic['09']['rank'][decodedata[0xd7]]
+    mode = old_types_dic['09']['mode'][decodedata[0x1e4] + decodedata[0x1e5]]
+    rep_info['base_info'] = f"{rank} {mode}"
     rep_info['base_infos'] = {
         "character": [],
         "shottype": "",
-        "rank": levels[rank],
-        "stage": modes[mode]
+        "rank": rank,
+        "stage": mode
     }
     rep_info['slowrate'] = 0.000
+    rep_info['date'] = decodedata[0xc4:0xc4 + 8].strip().decode()
     rep_info['stage_score'] = []
-    rep_info['screen_action'] = []
-    rep_info['keyboard_action'] = []
 
     is_match = (unsigned_int(decodedata, 0x44) != 0)
 
@@ -691,7 +641,6 @@ def hyzrep_cut(dat):
         rep_info['base_infos']['character'].append(character)
     else:
         stage_end = unsigned_int(decodedata, 0x48)
-
         for i in range(9):
             stage_offset = unsigned_int(decodedata, 0x20 + i * 0x4)
             if stage_offset != 0:
@@ -701,15 +650,15 @@ def hyzrep_cut(dat):
                 rep_info['base_info'] = "\n".join([rep_info['base_info'], character])
                 rep_info['base_infos']['character'].append(character)
                 stage_offsets.append(stage_offset)
-
         stage_offsets.append(stage_end)
 
+    rep_info['screen_action'] = []
+    rep_info['keyboard_action'] = []
     rep_info['z_frame'] = []
     rep_info['x_frame'] = []
     rep_info['c_frame'] = []
     rep_info['shift_frame'] = []
-
-    total_frame_count=0
+    total_frame_count = 0
 
     for i in range(len(stage_offsets) - 1):
         start = stage_offsets[i] + 0x20
@@ -717,12 +666,12 @@ def hyzrep_cut(dat):
         skey = []
         kkey = []
         for j in range(frame):
-            if (j % 60 == 0):
+            if j % 60 == 0:
                 skey.append(f'[{(j // 60):<6}]')
             framekey = unsigned_int(decodedata, start + j * 2) >> 4 & 0xf
             skey.append(skeys[framekey])
             kkey.append(kkeys[framekey])
-            if ((j + 1) % 60 == 0):
+            if (j + 1) % 60 == 0:
                 rep_info['screen_action'].append(''.join(skey))
                 rep_info['keyboard_action'].append(kkey)
                 skey = []
@@ -741,9 +690,7 @@ def hyzrep_cut(dat):
         rep_info['keyboard_action'].append(kkey)
 
     rep_info['error'] = []
-
     rep_info['frame_count'] = total_frame_count
-
     rep_info['z_frame'] = filter_constant_frame(rep_info['z_frame'])
     rep_info['x_frame'] = filter_constant_frame(rep_info['x_frame'])
     rep_info['shift_frame'] = filter_constant_frame(rep_info['shift_frame'])
@@ -752,16 +699,6 @@ def hyzrep_cut(dat):
 
 #endregion
 
-# 过滤按住的连续帧为按下帧
-# 只用于shift z x
-# 妖妖梦 永夜抄 花映冢
-def filter_constant_frame(frame_list):
-    result_frame_list=[]
-    for i, frame in enumerate(frame_list):
-        if i==0 or (frame!=frame_list[i-1]+1):
-            result_frame_list.append(frame)
-    return result_frame_list
-
 def threp_output(info, work):
     stage = info['stage']
 
@@ -776,11 +713,8 @@ def threp_output(info, work):
         "rank": rank,
         "stage": clear
     }
-    output['stage_score'] = []
-    output['player'] = info['player']
-    output['slowrate'] = info['slowrate']
-    output['date'] = info['date']
-    output['error'] = info['error']
+    for key in ['player', 'slowrate', 'date', 'error']:
+        output[key] = info[key]
 
     # 辉针城单面帧数出错，然后因文件头转到神灵庙的bug
     # 由于转到神灵庙，clear情况会读取为0
@@ -788,40 +722,35 @@ def threp_output(info, work):
         # 加入新的error
         output['error'].append({'type': "DDC frame error"})
 
-    for l in range(stage):
-        output['stage_score'].append(info['stages'][l]['score']*work_attr[work]['score_rate'])
-
-    output['screen_action']=[]
-    output['keyboard_action']=[]
+    output['stage_score'] = [info['stages'][i]['score'] * work_attr[work]['score_rate'] for i in range(stage)]
 
+    output['screen_action'] = []
+    output['keyboard_action'] = []
     output['z_frame'] = []
     output['x_frame'] = []
     output['c_frame'] = []
     output['shift_frame'] = []
-
-    total_frame_count=0
+    total_frame_count = 0
 
     # 文花帖DS的rep
-    if work=='125':
+    if work in ['125']:
         for l in range(stage):
+            skey, kkey = [], []
             stage_info = info['stages'][l]
             replaydata = stage_info['replay']
             replaydata.append(0x00)
             frame = stage_info['frame']
-            skey = []
-            kkey = []
             for i in range(frame):
-                if (i % 60 == 0):
+                if i % 60 == 0:
                     skey.append(f'[{(i // 60):<6}]')
                 framekey = unsigned_int(replaydata, i * 3) >> 3 & 0xf
                 skey.append(skeys[framekey])
                 kkey.append(kkeys[framekey])
-                if ((i + 1) % 60 == 0):
+                if (i + 1) % 60 == 0:
                     output['screen_action'].append(''.join(skey))
                     output['keyboard_action'].append(kkey)
-                    skey = []
-                    kkey = []
-                total_frame_count+=1
+                    skey, kkey = [], []
+                total_frame_count += 1
                 # 检测 z x c shift
                 left_hand_flag = unsigned_int(replaydata, i * 3) >> 8 & 0xf
                 if left_hand_flag == 1:
@@ -834,29 +763,26 @@ def threp_output(info, work):
             output['keyboard_action'].append(kkey)
     else:
         for l in range(stage):
+            skey, kkey = [], []
             stage_info = info['stages'][l]
             replaydata = stage_info['replay']
             frame = stage_info['frame']
-            skey = []
-            kkey = []
             for i in range(frame):
-                if (i % 60 == 0):
+                if i % 60 == 0:
                     skey.append(f'[{(i // 60):<6}]')
-                #print("stage", l, hex(i * 6))
                 framekey = unsigned_int(replaydata, i * 6) >> 4 & 0xf
                 skey.append(skeys[framekey])
                 kkey.append(kkeys[framekey])
-                if ((i + 1) % 60 == 0):
+                if (i + 1) % 60 == 0:
                     output['screen_action'].append(''.join(skey))
                     output['keyboard_action'].append(kkey)
-                    skey = []
-                    kkey = []
-                total_frame_count+=1
+                    skey, kkey = [], []
+                total_frame_count += 1
                 # 检测 z x c shift
                 left_hand_flag = unsigned_int(replaydata, i * 6) >> 16 & 0xf
                 c_flag = unsigned_int(replaydata, i * 6) >> 24 & 0xf
                 # 文花帖
-                if work == '95':
+                if work in ['95']:
                     if left_hand_flag == 2:
                         output['z_frame'].append(total_frame_count)
                     if left_hand_flag == 1:
@@ -869,15 +795,15 @@ def threp_output(info, work):
                     if left_hand_flag == 2:
                         output['x_frame'].append(total_frame_count)
                     # 大战争
-                    if work == '128':
+                    if work in ['128']:
                         if c_flag == 2:
                             output['c_frame'].append(total_frame_count)
                     # 神灵庙 辉针城 天邪鬼 绀珠传 天空璋
-                    elif work == '13' or work == '14' or work == '143' or work == '15' or work == '16':
+                    elif work in ['13', '14', '143', '15', '16']:
                         if c_flag == 10:
                             output['c_frame'].append(total_frame_count)
                     # 风神录
-                    if work == '10':
+                    if work in ['10']:
                         if left_hand_flag == 4:
                             output['shift_frame'].append(total_frame_count)
                     else:
@@ -886,31 +812,13 @@ def threp_output(info, work):
             output['screen_action'].append(''.join(skey))
             output['keyboard_action'].append(kkey)
 
-    output['frame_count']=total_frame_count
+    output['frame_count'] = total_frame_count
 
     return output
 
 def check_error(replay_info, error_str):
     return error_str in [error["type"] for error in replay_info["error"]]
 
-# 根据长度获取正确的帧数
-def true_frame(llength):
-    frame = floor(llength / (6 + 1/30))
-    if frame * 6 + ceil(frame / 30) == llength:
-        return frame
-    # 暴搜，，，
-    for i in range(frame - 10, frame + 10):
-        if i * 6 + ceil(i / 30) == llength:
-            return i
-    raise Exception("Can't correct the frame length")
-
-def correct_true_frame(llength):
-    try:
-        return true_frame(llength)
-    except Exception:
-        # 一直加65536，直到能够获取正确的帧数
-        return correct_true_frame(llength + 65536)
-
 def process_read_error(work, decodedata):
     # 解决th13和14文件头一样问题
     if work == '13':
@@ -947,7 +855,7 @@ def process_read_error(work, decodedata):
 
 def load(file):
     try:
-        file, buffer, flength = entry(file)
+        buffer = entry(file)
         decodedata, work = threp_decodedata(buffer)
         # 红魔乡/妖妖梦/永夜抄/花映冢
         if work in ['06', '07', '08', '09']:
